@@ -100,6 +100,39 @@ class FilterSyntaxRegex:
     )
 
 
+class Profile:
+
+    NONE = ()
+    LIGHT = (
+        "peter-lowe",
+        "stevenblack-hosts",
+        "tblock-base"
+    )
+    BALANCED = (
+        "adguard-cname",
+        "adguard-dns",
+        "adguard-tracking-servers",
+        "cpbl-filters",
+        "peter-lowe",
+        "stevenblack-hosts",
+        "tblock-base",
+        "tblock-security"
+    )
+    AGGRESSIVE = (
+        "adguard-cname",
+        "adguard-dns",
+        "adguard-tracking-servers",
+        "cpbl-filters",
+        "ddgtrackerradar",
+        "divested",
+        "mpvs-hosts",
+        "peter-lowe",
+        "stevenblack-hosts",
+        "tblock-base",
+        "tblock-security"
+    )
+
+
 # Code name to use to tell TBlock that a rule is a user-defined rule
 USER_RULE_PRIORITY = "!user"
 
