@@ -159,18 +159,6 @@ def updater(sync_repo: bool = False, frequency: int = 12, do_not_remove_pid: boo
             anti_hijack: bool = True, last_update: int = 0, force: bool = False, quiet: bool = False) -> None:
     process = SignalHandler()
     while not process.stopped:
-        try:
-            # Lock the database
-            lock_db()
-        except DatabaseLockedError:
-            # Wait one second before trying again and check for hosts hijack if enabled
-            if process.stopped:
-                break
-            if not quiet:
-                print(f'{Font.BOLD}==> Database locked, waiting for other instances to terminate{Font.DEFAULT}',
-                      end="\r")
-            time.sleep(1)
-            continue
 
         hours_left = time_left(last_update=last_update, frequency=frequency)
         if hours_left:
@@ -186,6 +174,25 @@ def updater(sync_repo: bool = False, frequency: int = 12, do_not_remove_pid: boo
                 time.sleep(1)
                 x += 1
 
+        if process.stopped:
+            if not do_not_remove_pid:
+                os.remove(Path.DAEMON_PID)
+            log_message("[tblockd] INFO:  caught {0}; PID: {1}; stopping now".format(process.signame, os.getpid()))
+            break
+
+        try:
+            # Lock the database
+            lock_db()
+        except DatabaseLockedError:
+            # Wait one second before trying again and check for hosts hijack if enabled
+            if process.stopped:
+                break
+            if not quiet:
+                print(f'{Font.BOLD}==> Database locked, waiting for other instances to terminate{Font.DEFAULT}',
+                      end="\r")
+            time.sleep(1)
+            continue
+
         if process.stopped:
             break
 
