@@ -33,7 +33,7 @@ import gzip
 from colorama import Fore, Style
 
 # Local modules
-from .const import FilterPermissions, WARNS, RulePolicy, USER_RULE_PRIORITY
+from .const import FilterPermissions, WARNS, RulePolicy, USER_RULE_PRIORITY, Profile
 from .style import Icon, Font, loading_icon
 from .config import Path, Var
 from .utils import fetch_file, prompt_user, is_url, check_root_access, lock_db, unlock_db
@@ -231,7 +231,8 @@ class Filter:
         if not os.path.isfile(self.tmp_file):
             raise FilterError("filter list needs to be downloaded before updating its rules")
         elif self.cache_is_up_to_date() and self.get_rules_count() == self.rules_count and not force:
-            print(f" {Icon.SUCCESS} " + "Filter list is up-to-date")
+            if not self.quiet:
+                print(f" {Icon.SUCCESS} " + "Filter list is up-to-date")
         else:
 
             # Remove rules from this filter lists
@@ -794,7 +795,7 @@ def rename_custom(filter_lists: list, do_not_prompt: bool = False, quiet: bool =
 
 def subscribe_custom(filter_lists: list, do_not_prompt: bool = False, quiet: bool = False,
                      sync_repo: bool = False, full_update: bool = False,
-                     permissions: FilterPermissions = Var.DEFAULT_PERMISSIONS, force: bool = False,
+                     permissions: FilterPermissions = Var.DEFAULT_PERMISSIONS_CUSTOM, force: bool = False,
                      custom_syntax: str = None) -> None:
     """
     Subscribe to a given list of filter lists
@@ -805,7 +806,7 @@ def subscribe_custom(filter_lists: list, do_not_prompt: bool = False, quiet: boo
     :param quiet: Optional. Do not display an output (false by default)
     :param sync_repo: Optional. Also sync the filter lists repository before subscribing (false by default)
     :param full_update: Optional. Also update all filter lists before subscribing (false by default)
-    :param permissions: Optional. Permissions to grant to filter list. Defaults to `tblock.DEFAULT_PERMISSIONS`
+    :param permissions: Optional. Permissions to grant to filter list. Defaults to `tblock.DEFAULT_PERMISSIONS_CUSTOM`
     :param force: Optional. Force updating, even if filter list or the filter list repository is up-to-date
     :param custom_syntax: Optional. Specify the syntax of the custom filter list
     """
@@ -1010,51 +1011,49 @@ def show_info(filter_lists: list, quiet: bool = False) -> None:
         raise FileNotFoundError("database does not exist yet. "
                                 "Please run 'tblock -Y' with admin privileges to create it")
     elif __check_filter_lists_validity_exists(filter_lists) and filter_lists:
-        # If quiet is set to True, do nothing
-        if not quiet:
-            # Show information about filter lists
+        # Show information about filter lists
+        print("------------------------------------")
+        for filter_id in filter_lists:
+            filter_object = Filter(filter_id)
+            print(f"{Font.BOLD}Filter ID       : {Font.DEFAULT}{filter_id}")
+            if filter_object.on_repo:
+                print(f"{Font.BOLD}Title           : {Font.DEFAULT}{filter_object.metadata['title']}")
+            print(f"{Font.BOLD}Source          : {Font.DEFAULT}{filter_object.source}")
+            if filter_object.subscribing:
+                print(f"{Font.BOLD}Subscribing     : {Font.DEFAULT}yes")
+                print(f"{Font.BOLD}Syntax          : {Font.DEFAULT}{filter_object.syntax}")
+                print(f"{Font.BOLD}Rules           : {Font.DEFAULT}{filter_object.get_rules_count()}")
+                print(f"{Font.BOLD}Permissions     : {Font.DEFAULT}{filter_object.permissions.compacted}")
+            elif filter_object.on_repo:
+                print(f"{Font.BOLD}Subscribing     : {Font.DEFAULT}no")
+                print(f"{Font.BOLD}Syntax          : {Font.DEFAULT}{filter_object.syntax}")
+            if filter_object.on_repo:
+                print(f"{Font.BOLD}Mirrors         : {Font.DEFAULT}{len(filter_object.mirrors)}")
+                print(f"{Font.BOLD}Custom          : {Font.DEFAULT}no")
+                print(f"{Font.BOLD}Homepage        : {Font.DEFAULT}{filter_object.metadata['homepage']}")
+                try:
+                    print(f"{Font.BOLD}License         : {Font.DEFAULT}{filter_object.metadata['license'][0]}")
+                except IndexError:
+                    print(f"{Font.BOLD}License         : {Font.DEFAULT}{filter_object.metadata['license']}")
+                try:
+                    print(f"{Font.BOLD}Status          : {Font.DEFAULT}{WARNS[filter_object.metadata['warning']]}")
+                except KeyError:
+                    pass
+                tag_list = ""
+                try:
+                    for tag in filter_object.metadata['tags']:
+                        tag_list += tag + " "
+                except KeyError:
+                    pass
+                print(f"{Font.BOLD}Tags            : {Font.DEFAULT}{tag_list}")
+                print(f"{Font.BOLD}Description     : {Font.DEFAULT}{filter_object.metadata['description']}")
+            else:
+                print(f"{Font.BOLD}Custom          : {Font.DEFAULT}yes")
             print("------------------------------------")
-            for filter_id in filter_lists:
-                filter_object = Filter(filter_id)
-                print(f"{Font.BOLD}Filter ID       : {Font.DEFAULT}{filter_id}")
-                if filter_object.on_repo:
-                    print(f"{Font.BOLD}Title           : {Font.DEFAULT}{filter_object.metadata['title']}")
-                print(f"{Font.BOLD}Source          : {Font.DEFAULT}{filter_object.source}")
-                if filter_object.subscribing:
-                    print(f"{Font.BOLD}Subscribing     : {Font.DEFAULT}yes")
-                    print(f"{Font.BOLD}Syntax          : {Font.DEFAULT}{filter_object.syntax}")
-                    print(f"{Font.BOLD}Rules           : {Font.DEFAULT}{filter_object.get_rules_count()}")
-                    print(f"{Font.BOLD}Permissions     : {Font.DEFAULT}{filter_object.permissions.compacted}")
-                elif filter_object.on_repo:
-                    print(f"{Font.BOLD}Subscribing     : {Font.DEFAULT}no")
-                    print(f"{Font.BOLD}Syntax          : {Font.DEFAULT}{filter_object.syntax}")
-                if filter_object.on_repo:
-                    print(f"{Font.BOLD}Mirrors         : {Font.DEFAULT}{len(filter_object.mirrors)}")
-                    print(f"{Font.BOLD}Custom          : {Font.DEFAULT}no")
-                    print(f"{Font.BOLD}Homepage        : {Font.DEFAULT}{filter_object.metadata['homepage']}")
-                    try:
-                        print(f"{Font.BOLD}License         : {Font.DEFAULT}{filter_object.metadata['license'][0]}")
-                    except IndexError:
-                        print(f"{Font.BOLD}License         : {Font.DEFAULT}{filter_object.metadata['license']}")
-                    try:
-                        print(f"{Font.BOLD}Status          : {Font.DEFAULT}{WARNS[filter_object.metadata['warning']]}")
-                    except KeyError:
-                        pass
-                    tag_list = ""
-                    try:
-                        for tag in filter_object.metadata['tags']:
-                            tag_list += tag + " "
-                    except KeyError:
-                        pass
-                    print(f"{Font.BOLD}Tags            : {Font.DEFAULT}{tag_list}")
-                    print(f"{Font.BOLD}Description     : {Font.DEFAULT}{filter_object.metadata['description']}")
-                else:
-                    print(f"{Font.BOLD}Custom          : {Font.DEFAULT}yes")
-                print("------------------------------------")
 
 
 def list_filter_lists(custom_only: bool = False, on_repo_only: bool = False, subscribing_only: bool = False,
-                      not_subscribing_only: bool = False) -> None:
+                      not_subscribing_only: bool = False, quiet: bool = False) -> None:
     """
     List filter lists stored in the database
 
@@ -1062,14 +1061,32 @@ def list_filter_lists(custom_only: bool = False, on_repo_only: bool = False, sub
     :param on_repo_only: List only filter lists that are available on the filter list repository
     :param subscribing_only: List only filter lists that are marked as "subscribed" in the database
     :param not_subscribing_only: List only filter lists that are not marked as "subscribed" in the database
+    :param quiet: Don't print verbose output
     """
     for f in get_all_filter_lists(subscribing_only=subscribing_only, not_subscribing_only=not_subscribing_only,
                                   custom_only=custom_only, from_repo_only=on_repo_only):
-        print(f)
+        show_search_info_filter_list(Filter(f), quiet)
+
+
+def show_search_info_filter_list(filter_list: Filter, quiet: bool = False):
+    if quiet:
+        print(filter_list.id)
+    elif filter_list.on_repo:
+        subscribing = f"{Font.BOLD}{Fore.GREEN}[subscribing]{Style.RESET_ALL}" if filter_list.subscribing else ""
+        if len(filter_list.metadata["description"]) > 90:
+            desc = filter_list.metadata["description"][:90] + " ..."
+        else:
+            desc = filter_list.metadata["description"]
+        print(f"{Font.BOLD}{filter_list.id}{Font.DEFAULT}: "
+              f"{filter_list.metadata['title']} {subscribing}\n    {desc}")
+    else:
+        print(f"{Font.BOLD}{filter_list.id}{Font.DEFAULT}: "
+              f"(no title) {Font.BOLD}{Fore.BLUE}[custom]{Style.RESET_ALL}\n    (no description)")
 
 
 def search_filter_lists(query: str, custom_only: bool = False, on_repo_only: bool = False,
-                        subscribing_only: bool = False, not_subscribing_only: bool = False) -> None:
+                        subscribing_only: bool = False, not_subscribing_only: bool = False,
+                        quiet: bool = False) -> None:
     """
     Search across filter lists (and their metadata) stored in the database
 
@@ -1078,6 +1095,7 @@ def search_filter_lists(query: str, custom_only: bool = False, on_repo_only: boo
     :param on_repo_only: List only filter lists that are available on the filter list repository
     :param subscribing_only: List only filter lists that are marked as "subscribed" in the database
     :param not_subscribing_only: List only filter lists that are not marked as "subscribed" in the database
+    :param quiet: Don't print verbose output
     """
     regex_query = re.compile(query, re.IGNORECASE)
 
@@ -1087,15 +1105,15 @@ def search_filter_lists(query: str, custom_only: bool = False, on_repo_only: boo
     for filter_id in filters_list:
         filter_match = Filter(filter_id)
         if re.findall(regex_query, filter_match.id):
-            print(filter_id)
+            show_search_info_filter_list(filter_match, quiet)
         elif filter_match.on_repo and re.findall(regex_query, filter_match.metadata['title']):
-            print(filter_id)
+            show_search_info_filter_list(filter_match, quiet)
         elif filter_match.on_repo and re.findall(regex_query, filter_match.metadata['description']):
-            print(filter_id)
-        else:
+            show_search_info_filter_list(filter_match, quiet)
+        elif filter_match.on_repo:
             for tag in filter_match.metadata['tags']:
                 if filter_match.on_repo and re.findall(regex_query, tag):
-                    print(filter_id)
+                    show_search_info_filter_list(filter_match, quiet)
                     break
 
 
@@ -1368,3 +1386,47 @@ def sync_filter_list_repo(quiet: bool = False, force: bool = False, lock_databas
         # Unlock the database
         if lock_database:
             unlock_db()
+
+
+def setup_profile(profile: tuple, quiet: bool = False) -> None:
+    # Check root access
+    if not check_root_access():
+        raise PermissionError("you need to run as root to perform this operation")
+    # Lock the database
+    subscribe(list(profile), do_not_prompt=True, quiet=quiet, sync_repo=True)
+
+
+def init_tblock() -> None:
+    # Check root access
+    if not check_root_access():
+        raise PermissionError("you need to run as root to perform this operation")
+
+    print(f"\n{Font.BOLD}> Welcome to TBlock!{Font.DEFAULT}\n\n\n"
+          ":: Please choose the profile that suits your needs the best:"
+          "\n\n [0] None: lets you configure everything yourself\n"
+          " [1] Light: light protection, some ads and trackers won't be blocked\n"
+          " [2] Balanced: perfect solution for regular users\n"
+          " [3] Aggressive: powerful, yet it may break some web pages\n")
+    choice = None
+    while type(choice) != tuple:
+        answer = input("Your choice [default=2]: ")
+        if answer == "0":
+            choice = Profile.NONE
+        elif answer == "1":
+            choice = Profile.LIGHT
+        elif answer == "2" or answer == "":
+            choice = Profile.BALANCED
+        elif answer == "3":
+            choice = Profile.AGGRESSIVE
+        else:
+            choice = None
+    else:
+        print("\n")
+        setup_profile(choice)
+        print(f"\n{Font.BOLD}> Wonderful! TBlock is now protecting you!{Font.DEFAULT}\n\n"
+              f"To disable it, simply run:\n    $ {Fore.GREEN}tblock{Style.RESET_ALL} -D"
+              f"\nAnd then, to enable it again:\n    $ {Fore.GREEN}tblock{Style.RESET_ALL} -E\n"
+              f"It is also highly recommended to read the documentation: "
+              f"https://tblock.codeberg.page/docs/")
+        print(f"\n{Font.BOLD}> The setup is now finished{Font.DEFAULT}.\nHit ENTER to exit the program.")
+        input()
