@@ -40,30 +40,47 @@ from .hosts import update_hosts, remove_from_hosts, add_to_hosts
 
 class Rule:
 
-    def __init__(self, domain: str) -> None:
+    def __init__(self, domain: str, user_rule: bool = False) -> None:
         """
         User rule object
         :param domain: The domain to use
+        :param user_rule: The rule must strictly be an user rule
         """
         self.domain = urllib3.get_host(domain)[1]
         # Fetch rule data from the database
-        with sqlite3.connect(Path.DATABASE) as conn:
+        with sqlite3.connect(Path.RULES_DATABASE) as conn:
             data = conn.cursor().execute(
-                'SELECT "policy", "filter_id", "ip" FROM "rules" WHERE domain=?;',
+                'SELECT "policy", "ip" FROM r WHERE domain=?;',
                 (self.domain,)
             ).fetchone()
         self.exists = bool(data)
         self.policy = data[0] if data else None
-        self.filter_id = data[1] if data else None
-        self.ip = data[2] if data else None
-        self.is_user_rule = True if self.filter_id == USER_RULE_PRIORITY else False
+        self.filter_id = "!user" if data else None
+        self.ip = data[1] if data else None
+        self.is_user_rule = True
+        if not data and not user_rule:
+            with sqlite3.connect(Path.DATABASE) as conn:
+                data = conn.cursor().execute(
+                    'SELECT "policy", "filter_id", "ip" FROM rules WHERE domain=?;',
+                    (self.domain,)
+                ).fetchone()
+            self.exists = bool(data)
+            self.policy = data[0] if data else None
+            self.filter_id = data[1] if data else None
+            self.ip = data[2] if data else None
+            self.is_user_rule = False
 
     def wildcard_exists(self) -> bool:
-        with sqlite3.connect(Path.DATABASE) as conn:
-            data = conn.cursor().execute("SELECT domain FROM rules WHERE domain LIKE '%*%';")
+        with sqlite3.connect(Path.RULES_DATABASE) as conn:
+            data = conn.cursor().execute("SELECT domain FROM r WHERE domain LIKE '%*%';")
         for rule in data:
             if re.match(re.compile(rule[0].replace(".", "\\.").replace("*", ".*")), self.domain):
                 return True
+        with sqlite3.connect(Path.DATABASE) as conn:
+            data2 = conn.cursor().execute("SELECT domain FROM rules WHERE domain LIKE '%*%';")
+        for rule in data2:
+            if re.match(re.compile(rule[0].replace(".", "\\.").replace("*", ".*")), self.domain):
+                return True
         else:
             return False
 
@@ -91,39 +108,45 @@ class Rule:
 
                         if policy == RulePolicy.REDIRECT:
                             ip_address = ipaddress.ip_address(ip)
-                            if self.exists:
-                                with sqlite3.connect(Path.DATABASE) as conn:
+                            if self.exists and self.filter_id == USER_RULE_PRIORITY:
+                                with sqlite3.connect(Path.RULES_DATABASE) as conn:
                                     conn.cursor().execute(
-                                        "UPDATE rules SET policy=?, ip=?, filter_id=? WHERE domain=?;",
-                                        (policy, ip_address.compressed, USER_RULE_PRIORITY, self.domain)
+                                        "UPDATE r SET policy=?, ip=? WHERE domain=?;",
+                                        (policy, ip_address.compressed, self.domain)
                                     )
                                     conn.commit()
                                 self.__init__(self.domain)
                             else:
-                                with sqlite3.connect(Path.DATABASE) as conn:
+                                if self.exists:
+                                    with sqlite3.connect(Path.DATABASE) as conn:
+                                        conn.cursor().execute("DELETE FROM rules WHERE domain=?", (self.domain,))
+                                with sqlite3.connect(Path.RULES_DATABASE) as conn:
                                     conn.cursor().execute(
-                                        "INSERT INTO rules (domain, policy, ip, filter_id)"
-                                        "VALUES (?, ?, ?, ?);",
-                                        (self.domain, policy, ip_address.compressed, USER_RULE_PRIORITY)
+                                        "INSERT INTO r (domain, policy, ip)"
+                                        "VALUES (?, ?, ?);",
+                                        (self.domain, policy, ip_address.compressed)
                                     )
                                     conn.commit()
                                 self.__init__(self.domain)
 
                         else:
-                            if self.exists:
-                                with sqlite3.connect(Path.DATABASE) as conn:
+                            if self.exists and self.filter_id == USER_RULE_PRIORITY:
+                                with sqlite3.connect(Path.RULES_DATABASE) as conn:
                                     conn.cursor().execute(
-                                        "UPDATE rules SET policy=?, ip=?, filter_id=? WHERE domain=?;",
-                                        (policy, None, USER_RULE_PRIORITY, self.domain)
+                                        "UPDATE r SET policy=?, ip=? WHERE domain=?;",
+                                        (policy, None, self.domain)
                                     )
                                     conn.commit()
                                 self.__init__(self.domain)
                             else:
-                                with sqlite3.connect(Path.DATABASE) as conn:
+                                if self.exists:
+                                    with sqlite3.connect(Path.DATABASE) as conn:
+                                        conn.cursor().execute("DELETE FROM rules WHERE domain=?", (self.domain,))
+                                with sqlite3.connect(Path.RULES_DATABASE) as conn:
                                     conn.cursor().execute(
-                                        "INSERT INTO rules (domain, policy, ip, filter_id)"
-                                        "VALUES (?, ?, ?, ?);",
-                                        (self.domain, policy, None, USER_RULE_PRIORITY)
+                                        "INSERT INTO r (domain, policy, ip)"
+                                        "VALUES (?, ?, ?);",
+                                        (self.domain, policy, None)
                                     )
                                     conn.commit()
                                 self.__init__(self.domain)
@@ -152,9 +175,9 @@ class Rule:
             __msg = "Deleting rule for domain: {0}".format(self.domain)
             if not quiet:
                 print(f" {loading_icon(1)} {__msg}", end="\r")
-            with sqlite3.connect(Path.DATABASE) as conn:
+            with sqlite3.connect(Path.RULES_DATABASE) as conn:
                 conn.cursor().execute(
-                    "DELETE FROM rules WHERE domain=?;",
+                    "DELETE FROM r WHERE domain=?;",
                     (self.domain,)
                 )
                 conn.commit()
@@ -171,6 +194,11 @@ def __remove_allowed_matches(quiet: bool = False) -> dict:
     wildcards = cursor.execute(
         'SELECT domain FROM rules WHERE policy=? AND domain LIKE "%*%";', (RulePolicy.ALLOW,)
     ).fetchall()
+    conn.close()
+    conn = sqlite3.connect(Path.RULES_DATABASE)
+    cursor = conn.cursor()
+    wildcards += cursor.execute('SELECT domain FROM r WHERE policy=? AND domain LIKE "%*%";', (RulePolicy.ALLOW,))
+    conn.close()
 
     cnt = multiprocessing.Value('i', 0)
 
@@ -204,6 +232,16 @@ def check_wildcard_domains(i) -> dict:
         cursor.execute("DELETE FROM rules WHERE domain=?;", (q[0],))
         matches[q[0]] = q[1]
     conn.commit()
+    conn.close()
+    conn = sqlite3.connect(Path.RULES_DATABASE)
+    cursor = conn.cursor()
+    query = cursor.execute("SELECT domain, ip FROM r WHERE domain LIKE ? AND policy != ?;",
+                           (i[0].replace("*", "%"), RulePolicy.ALLOW)).fetchall()
+    for q in query:
+        cursor.execute("DELETE FROM r WHERE domain=?;", (q[0],))
+        matches[q[0]] = q[1]
+    conn.commit()
+    conn.close()
     return matches
 
 
@@ -372,30 +410,39 @@ def get_all_rules(from_filter_lists: list = None, user_only: bool = False, stand
                                 "Please run 'tblock -Y' with admin privileges to create it")
     else:
         output = []
-        with sqlite3.connect(Path.DATABASE) as conn:
-            if from_filter_lists:
+        data2 = None
+        if from_filter_lists:
+            with sqlite3.connect(Path.DATABASE) as conn:
                 for f in from_filter_lists:
                     data = conn.cursor().execute(
                         'SELECT "domain" FROM "rules" WHERE filter_id=? ORDER BY domain ASC;',
                         (f,)
                     )
-            elif standard_only:
+        elif standard_only:
+            with sqlite3.connect(Path.DATABASE) as conn:
                 data = conn.cursor().execute(
-                    'SELECT "domain" FROM "rules" WHERE filter_id!=? ORDER BY domain ASC;',
-                    (USER_RULE_PRIORITY,)
+                    'SELECT "domain" FROM "rules" ORDER BY domain ASC;'
                 )
-            elif user_only:
+        elif user_only:
+            with sqlite3.connect(Path.RULES_DATABASE) as conn:
                 data = conn.cursor().execute(
-                    'SELECT "domain" FROM "rules" WHERE filter_id=? ORDER BY domain ASC;',
-                    (USER_RULE_PRIORITY,)
+                    'SELECT "domain" FROM "r" ORDER BY domain ASC;'
                 )
-            else:
+        else:
+            with sqlite3.connect(Path.RULES_DATABASE) as conn:
                 data = conn.cursor().execute(
+                    'SELECT "domain" FROM "r" ORDER BY domain ASC;'
+                )
+            with sqlite3.connect(Path.DATABASE) as conn:
+                data2 = conn.cursor().execute(
                     'SELECT "domain" FROM "rules" ORDER BY domain ASC;'
                 )
 
         for rule in data:
             output.append(rule[0])
+        if data2 is not None:
+            for rule in data2:
+                output.append(rule[0])
         return output
 
 
@@ -413,26 +460,31 @@ def list_rules(from_filter_lists: list = None, user_only: bool = False, standard
         raise FileNotFoundError("database does not exist yet. "
                                 "Please run 'tblock -Y' with admin privileges to create it")
     else:
-
-        with sqlite3.connect(Path.DATABASE) as conn:
-            if from_filter_lists:
+        data2 = None
+        if from_filter_lists:
+            with sqlite3.connect(Path.DATABASE) as conn:
                 for f in from_filter_lists:
                     data = conn.cursor().execute(
                         'SELECT "domain", "policy", "ip" FROM "rules" WHERE filter_id=? ORDER BY domain ASC;',
                         (f,)
                     )
-            elif standard_only:
+        elif standard_only:
+            with sqlite3.connect(Path.DATABASE) as conn:
                 data = conn.cursor().execute(
-                    'SELECT "domain", "policy", "ip" FROM "rules" WHERE filter_id!=? ORDER BY domain ASC;',
-                    (USER_RULE_PRIORITY,)
+                    'SELECT "domain", "policy", "ip" FROM "rules" ORDER BY domain ASC;'
                 )
-            elif user_only:
+        elif user_only:
+            with sqlite3.connect(Path.RULES_DATABASE) as conn:
                 data = conn.cursor().execute(
-                    'SELECT "domain", "policy", "ip" FROM "rules" WHERE filter_id=? ORDER BY domain ASC;',
-                    (USER_RULE_PRIORITY,)
+                    'SELECT "domain", "policy", "ip" FROM "r" ORDER BY domain ASC;'
                 )
-            else:
+        else:
+            with sqlite3.connect(Path.RULES_DATABASE) as conn:
                 data = conn.cursor().execute(
+                    'SELECT "domain", "policy", "ip" FROM "r" ORDER BY domain ASC;'
+                )
+            with sqlite3.connect(Path.DATABASE) as conn:
+                data2 = conn.cursor().execute(
                     'SELECT "domain", "policy", "ip" FROM "rules" ORDER BY domain ASC;'
                 )
 
@@ -443,8 +495,18 @@ def list_rules(from_filter_lists: list = None, user_only: bool = False, standard
                 print("BLOCK    " + rule[0])
             elif rule[1] == RulePolicy.REDIRECT:
                 print("REDIRECT " + rule[0] + " -> " + rule[2])
+        if data2 is not None:
+            for rule in data2:
+                if rule[1] == RulePolicy.ALLOW:
+                    print("ALLOW    " + rule[0])
+                elif rule[1] == RulePolicy.BLOCK:
+                    print("BLOCK    " + rule[0])
+                elif rule[1] == RulePolicy.REDIRECT:
+                    print("REDIRECT " + rule[0] + " -> " + rule[2])
 
 
 def get_rules_count() -> int:
     with sqlite3.connect(Path.DATABASE) as db:
-        return db.cursor().execute('SELECT COUNT() FROM rules;').fetchone()[0]
+        count = db.cursor().execute('SELECT COUNT() FROM rules;').fetchone()[0]
+    with sqlite3.connect(Path.RULES_DATABASE) as db:
+        return count + db.cursor().execute('SELECT COUNT() FROM r;').fetchone()[0]
